@@ -23,7 +23,7 @@ class PryLexer(DelegatingLexer):
     """
     name = 'Pry'
     aliases = ['pry']
-    filenames = '*.pry'
+    filenames = ['*.pry']
 
     def __init__(self, **options):
         super(PryLexer, self).__init__(RubyLexer, PryPrefixLexer, **options)
